
##  gettz -- Retrieve Timezone Information from System
##
##  Copyright (C) 2016  Dirk Eddelbuettel <edd@debian.org>
##
##  This file is part of gettz
##
##  gettz is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 2 of the License, or
##  (at your option) any later version.
##
##  gettz is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with gettz.  If not, see <http://www.gnu.org/licenses/>.

gettz <- function() {
    val <- .Call(gettz_impl);
    return(val)                         #return visibly
}
